@@ -69,56 +69,31 @@ static gpointer session_object = NULL;
 
 static void
 on_info (GdmGreeterClient  *client,
-         const char        *service_name,
          const char        *text,
          GdmGreeterSession *session)
 {
         g_debug ("GdmGreeterSession: Info: %s", text);
 
-        gdm_greeter_login_window_info (GDM_GREETER_LOGIN_WINDOW (session->priv->login_window), service_name, text);
+        gdm_greeter_login_window_info (GDM_GREETER_LOGIN_WINDOW (session->priv->login_window), text);
 }
 
 static void
 on_problem (GdmGreeterClient  *client,
-            const char        *service_name,
             const char        *text,
             GdmGreeterSession *session)
 {
         g_debug ("GdmGreeterSession: Problem: %s", text);
 
-        gdm_greeter_login_window_problem (GDM_GREETER_LOGIN_WINDOW (session->priv->login_window), service_name, text);
-}
-
-static void
-on_service_unavailable (GdmGreeterClient  *client,
-                        const char        *service_name,
-                        GdmGreeterSession *session)
-{
-        g_debug ("GdmGreeterSession: Service Unavailable: %s", service_name);
-
-        gdm_greeter_login_window_service_unavailable (GDM_GREETER_LOGIN_WINDOW (session->priv->login_window), service_name);
+        gdm_greeter_login_window_problem (GDM_GREETER_LOGIN_WINDOW (session->priv->login_window), text);
 }
 
 static void
 on_ready (GdmGreeterClient  *client,
-          const char        *service_name,
           GdmGreeterSession *session)
 {
         g_debug ("GdmGreeterSession: Ready");
 
-        gdm_greeter_login_window_ready (GDM_GREETER_LOGIN_WINDOW (session->priv->login_window),
-                                        service_name);
-}
-
-static void
-on_conversation_stopped (GdmGreeterClient  *client,
-                         const char        *service_name,
-                         GdmGreeterSession *session)
-{
-        g_debug ("GdmGreeterSession: Conversation '%s' stopped", service_name);
-
-        gdm_greeter_login_window_conversation_stopped (GDM_GREETER_LOGIN_WINDOW (session->priv->login_window),
-                                                       service_name);
+        gdm_greeter_login_window_ready (GDM_GREETER_LOGIN_WINDOW (session->priv->login_window));
 }
 
 static void
@@ -132,6 +107,28 @@ on_reset (GdmGreeterClient  *client,
         gdm_greeter_login_window_reset (GDM_GREETER_LOGIN_WINDOW (session->priv->login_window));
 }
 
+static void
+on_authentication_failed (GdmGreeterClient  *client,
+                          GdmGreeterSession *session)
+{
+        g_debug ("GdmGreeterSession: Authentication failed");
+
+        session->priv->num_tries++;
+
+        if (session->priv->num_tries < MAX_LOGIN_TRIES) {
+                g_debug ("GdmGreeterSession: Retrying login (%d)",
+                         session->priv->num_tries);
+
+                gdm_greeter_login_window_authentication_failed (GDM_GREETER_LOGIN_WINDOW (session->priv->login_window));
+        } else {
+                g_debug ("GdmGreeterSession: Maximum number of login tries exceeded (%d) - resetting",
+                         session->priv->num_tries - 1);
+                session->priv->num_tries = 0;
+
+                gdm_greeter_login_window_reset (GDM_GREETER_LOGIN_WINDOW (session->priv->login_window));
+        }
+}
+
 static void
 show_or_hide_user_options (GdmGreeterSession *session,
                            const char        *username)
@@ -180,44 +177,33 @@ on_timed_login_requested (GdmGreeterClient  *client,
 }
 
 static void
-on_session_opened (GdmGreeterClient  *client,
-                   const char        *service_name,
-                   GdmGreeterSession *session)
+on_user_authorized (GdmGreeterClient  *client,
+                    GdmGreeterSession *session)
 {
-        g_debug ("GdmGreeterSession: session opened");
-        gdm_greeter_login_window_session_opened (GDM_GREETER_LOGIN_WINDOW (session->priv->login_window), service_name);
+        g_debug ("GdmGreeterSession: user authorized");
+        gdm_greeter_login_window_user_authorized (GDM_GREETER_LOGIN_WINDOW (session->priv->login_window));
 }
 
 static void
 on_info_query (GdmGreeterClient  *client,
-               const char        *service_name,
                const char        *text,
                GdmGreeterSession *session)
 {
         g_debug ("GdmGreeterSession: Info query: %s", text);
 
-        gdm_greeter_login_window_info_query (GDM_GREETER_LOGIN_WINDOW (session->priv->login_window), service_name, text);
+        gdm_greeter_login_window_info_query (GDM_GREETER_LOGIN_WINDOW (session->priv->login_window), text);
 }
 
 static void
 on_secret_info_query (GdmGreeterClient  *client,
-                      const char        *service_name,
                       const char        *text,
                       GdmGreeterSession *session)
 {
         g_debug ("GdmGreeterSession: Secret info query: %s", text);
 
-        gdm_greeter_login_window_secret_info_query (GDM_GREETER_LOGIN_WINDOW (session->priv->login_window), service_name, text);
+        gdm_greeter_login_window_secret_info_query (GDM_GREETER_LOGIN_WINDOW (session->priv->login_window), text);
 }
 
-static void
-on_start_conversation (GdmGreeterLoginWindow *login_window,
-                       const char            *service_name,
-                       GdmGreeterSession     *session)
-{
-        gdm_greeter_client_call_start_conversation (session->priv->client,
-                                                    service_name);
-}
 static void
 on_begin_auto_login (GdmGreeterLoginWindow *login_window,
                      const char            *username,
@@ -229,32 +215,26 @@ on_begin_auto_login (GdmGreeterLoginWindow *login_window,
 
 static void
 on_begin_verification (GdmGreeterLoginWindow *login_window,
-                       const char            *service_name,
                        GdmGreeterSession     *session)
 {
-        gdm_greeter_client_call_begin_verification (session->priv->client,
-                                                    service_name);
+        gdm_greeter_client_call_begin_verification (session->priv->client);
 }
 
 static void
 on_begin_verification_for_user (GdmGreeterLoginWindow *login_window,
-                                const char            *service_name,
                                 const char            *username,
                                 GdmGreeterSession     *session)
 {
         gdm_greeter_client_call_begin_verification_for_user (session->priv->client,
-                                                             service_name,
                                                              username);
 }
 
 static void
 on_query_answer (GdmGreeterLoginWindow *login_window,
-                 const char            *service_name,
                  const char            *text,
                  GdmGreeterSession     *session)
 {
         gdm_greeter_client_call_answer_query (session->priv->client,
-                                              service_name,
                                               text);
 }
 
@@ -267,6 +247,14 @@ on_select_session (GdmGreeterLoginWindow *login_window,
                                                 text);
 }
 
+static void
+on_select_language (GdmGreeterSession     *session,
+                    const char            *text)
+{
+        gdm_greeter_client_call_select_language (session->priv->client,
+                                                 text);
+}
+
 static void
 on_select_user (GdmGreeterLoginWindow *login_window,
                 const char            *text,
@@ -292,10 +280,9 @@ on_disconnected (GdmGreeterSession     *session)
 
 static void
 on_start_session (GdmGreeterLoginWindow *login_window,
-                  const char            *service_name,
                   GdmGreeterSession     *session)
 {
-        gdm_greeter_client_call_start_session_when_ready (session->priv->client, service_name, TRUE);
+        gdm_greeter_client_call_start_session_when_ready (session->priv->client, TRUE);
 }
 
 static int
@@ -380,10 +367,7 @@ toggle_login_window (GdmGreeterSession *session,
                 is_local = gdm_greeter_client_get_display_is_local (session->priv->client);
                 g_debug ("GdmGreeterSession: Starting a login window local:%d", is_local);
                 session->priv->login_window = gdm_greeter_login_window_new (is_local);
-                g_signal_connect (session->priv->login_window,
-                                  "start-conversation",
-                                  G_CALLBACK (on_start_conversation),
-                                  session);
+
                 g_signal_connect (session->priv->login_window,
                                   "begin-auto-login",
                                   G_CALLBACK (on_begin_auto_login),
@@ -571,22 +555,18 @@ gdm_greeter_session_init (GdmGreeterSession *session)
                           "problem",
                           G_CALLBACK (on_problem),
                           session);
-        g_signal_connect (session->priv->client,
-                          "service-unavailable",
-                          G_CALLBACK (on_service_unavailable),
-                          session);
         g_signal_connect (session->priv->client,
                           "ready",
                           G_CALLBACK (on_ready),
                           session);
-        g_signal_connect (session->priv->client,
-                          "conversation-stopped",
-                          G_CALLBACK (on_conversation_stopped),
-                          session);
         g_signal_connect (session->priv->client,
                           "reset",
                           G_CALLBACK (on_reset),
                           session);
+        g_signal_connect (session->priv->client,
+                          "authentication-failed",
+                          G_CALLBACK (on_authentication_failed),
+                          session);
         g_signal_connect (session->priv->client,
                           "selected-user-changed",
                           G_CALLBACK (on_selected_user_changed),
@@ -604,8 +584,8 @@ gdm_greeter_session_init (GdmGreeterSession *session)
                           G_CALLBACK (on_timed_login_requested),
                           session);
         g_signal_connect (session->priv->client,
-                          "session-opened",
-                          G_CALLBACK (on_session_opened),
+                          "user-authorized",
+                          G_CALLBACK (on_user_authorized),
                           session);
 
         /* We want to listen for panel mnemonics even if the
